@@ -1,14 +1,16 @@
 package Acme::PrettyCure::Girl::CureSunshine;
 use utf8;
-use Moo;
+use Any::Moose;
 
-with qw/Acme::PrettyCure::Girl::Role Acme::PrettyCure::Girl::Role::HeartCatch/;
+with 'Acme::PrettyCure::Girl::Role';
 
 sub human_name   {'明堂院いつき'}
 sub precure_name {'キュアサンシャイン'}
 sub age          {14}
 sub challenge { qw(陽の光浴びる一輪の花、キュアサンシャイン!) }
-sub color { 227 }
-sub image_url { 'http://www.toei-anim.co.jp/tv/hc_precure/images/chara/chara14.jpg' }
+
+
+no Any::Moose;
+__PACKAGE__->meta->make_immutable;
 
 1;
