@@ -1,6 +1,6 @@
 package Acme::PrettyCure::Girl::ShinyLuminous;
 use utf8;
-use Moo;
+use Any::Moose;
 
 with 'Acme::PrettyCure::Girl::Role';
 
@@ -9,7 +9,6 @@ sub precure_name {'シャイニー・ルミナス'}
 sub birthday     { Time::Piece->( '1990/02/02', '%Y/%m/%d' ) }
 sub age          {13}
 sub blood_type   {'AB'}
-sub image_url    {'http://www.toei-anim.co.jp/tv/precure_MH/image/hikari/p01.gif'}
 sub challenge {
     qw(
        輝く命、シャイニールミナス!
@@ -17,6 +16,8 @@ sub challenge {
        全てをひとつにするために
     )
 }
-sub color { 213 }
+
+no Any::Moose;
+__PACKAGE__->meta->make_immutable;
 
 1;
